OC.L10N.register(
    "firstrunwizard",
    {
    "Privacy" : "ສ່ວນຕົວ",
    "Community" : "ຊຸມຊົນ",
    "Schedule work & meetings, synced with all your devices." : "ຕາຕະລາງການເຮັດວຽກ & ການປະຊຸມ, synced ກັບອຸປະກອນທັງຫມົດຂອງທ່ານ.",
    "Keep your colleagues and friends in one place without leaking their private info." : "ຮັກສາເພື່ອນຮ່ວມງານ ແລະ ຫມູ່ ເພື່ອນ ຂອງ ທ່ານ ໄວ້ ໃນບ່ອນດຽວໂດຍບໍ່ໄດ້ ໃຫ້ຂໍ້ ຄວາມ ສ່ວນ ຕົວ ຂອງ ເຂົາ ເຈົ້າຮົ່ວໄຫຼ .",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "ແອັບອີເມວລວມເຂົ້າກັບ ຟາຍຕ່າງໆ, ເບີຕິດຕໍ່ ແລະ ປະຕິທິນ",
    "About" : "ກ່ຽວກັບ",
    "Copy link" : "ສຳເນົາລິງ",
    "Copied!" : "ກ໋ອບປີ້ແລ້ວ",
    "Not supported!" : "ບໍ່ຊັບຟອດ",
    "Press Ctrl-C to copy." : "ກົດ Ctrl-C ເພື່ອ copy"
},
"nplurals=1; plural=0;");
